/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Bullet.h
// Desc: This entity is used to shoot down enemies (and maybe also allies).
//       Originally, this entity was used only for plane bullets, however it
//       has been extended so that it can be used for soldier bullets as well.
//
// Note: It would be cleaner and more OO to break this down into subclasses
//       for the different types of bullet. However this has not been done
//       yet because it was much quicker and simpler to leave it as is.
//
//       All bullet vectors must be unit vectors
//------------------------------------------------------------------------------

#ifndef _BULLET_H_
#define _BULLET_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "CamelMath.h"
#include "Entity.h"

class Bullet : public Entity
{
public:
    enum BULLET_TYPE {
        PLANE_BULLET,
        SOLDIER_BULLET,
        TANK_BULLET,
        NUM_BULLET_TYPES
    };
protected:
	// Speed of bullet in pixels per second
	static const float BULLET_SPEED;
    
    BULLET_TYPE BulletType;
    float Velocity;     // Pixels per second
    // This entity uses a vector for its direction rather than one of 
    // the fixed world directions
    XY_COMPONENT XY_Direction;  
    uint Range;
    float RangeTravelled;
    
    Bullet();
public:
    Bullet(Level *L, Point2D CentrePos, XY_COMPONENT XY_Direction, 
        BULLET_TYPE BulletType, uint Range, ENT_SIDE Side);
    ~Bullet();

    BULLET_TYPE GetBulletType() { return BulletType; }
    void Update(uint dt);
    void HandleCollision(Entity *AnEntity);
};

#endif // _BULLET_H_
