/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Camel.h
// Desc: Defines and structs used throughout the program
//------------------------------------------------------------------------------

#ifndef _CAMEL_H_
#define _CAMEL_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#ifdef WIN32

#include <windows.h>

#endif
#include "globals.h"

#include "SDL.h"

//------------------------------------------------------------------------------
// Typedefs and Structs
//------------------------------------------------------------------------------

struct COLOUR_RGBA {
    uchar r, g, b, a;
};

//------------------------------------------------------------------------------
// Defines and Constants
//------------------------------------------------------------------------------
#define CAM_APPLICATION_TITLE       "Camel"

// BPP of surfaces used internally, it may or may not match that used for 
// the screen
const int CAM_INTERNAL_SURFACE_BPP = 32;     

// Some conversion factors to relate measurements in the game to the real world
#define CAM_PIXELS_PER_METRE        5.0f

#define CAM_DATA_DIR                "data"
#define CAM_GRAPHICS_DIR            CAM_DATA_DIR "/graphics"
#define CAM_LEVELS_DIR              CAM_DATA_DIR "/levels"
#define CAM_INTROS_DIR              CAM_LEVELS_DIR "/intros"
#define CAM_MUSIC_DIR               CAM_DATA_DIR "/music"
#define CAM_PARALLAX_DIR            CAM_LEVELS_DIR "/parallax"
#define CAM_SOUNDS_DIR              CAM_DATA_DIR "/sounds"
#define CAM_TILESETS_DIR            CAM_LEVELS_DIR "/tilesets"
#define CAM_SPRITES_IMG             CAM_GRAPHICS_DIR "/sprites.png"
#define CAM_MAIN_FONT               CAM_GRAPHICS_DIR "/uifont.png"

#define CAM_PARAGUI_THEME           CAM_DATA_DIR "/camelgui"

#define CAM_GOOD_PLATOON_PIC        CAM_GRAPHICS_DIR "/goodplatoonpic.png"
#define CAM_EVIL_PLATOON_PIC        CAM_GRAPHICS_DIR "/evilplatoonpic.png"

// Sound effects
#define CAM_PLANE_ENGINE_WAV        CAM_SOUNDS_DIR "/planengi.wav"
#define CAM_PLANE_GUNFIRE_WAV       CAM_SOUNDS_DIR "/planfire.wav"
#define CAM_BOMB_EXPLOSION_WAV      CAM_SOUNDS_DIR "/bombexpl.wav"
#define CAM_MENU_CLICK_WAV          CAM_SOUNDS_DIR "/menuclick.wav"
#define SOLDIER_GUN_0_WAV           CAM_SOUNDS_DIR "/db_gun_01.wav"
#define SOLDIER_GUN_1_WAV           CAM_SOUNDS_DIR "/db_gun_02.wav"
#define SOLDIER_GUN_2_WAV           CAM_SOUNDS_DIR "/db_gun_03.wav"
#define SOLDIER_GUN_3_WAV           CAM_SOUNDS_DIR "/db_gun_04.wav"
#define SOLDIER_GUN_4_WAV           CAM_SOUNDS_DIR "/db_gun_05.wav"
#define SOLDIER_GUN_5_WAV           CAM_SOUNDS_DIR "/db_gun_06.wav"
#define SOLDIER_GUN_6_WAV           CAM_SOUNDS_DIR "/db_gun_07.wav"
#define SOLDIER_SCREAM_0_WAV        CAM_SOUNDS_DIR "/db_scream_01.wav"
#define SOLDIER_SCREAM_1_WAV        CAM_SOUNDS_DIR "/db_scream_02.wav"
#define SOLDIER_SCREAM_2_WAV        CAM_SOUNDS_DIR "/scream_03.wav"
#define SOLDIER_SCREAM_3_WAV        CAM_SOUNDS_DIR "/scream_04.wav"
#define SOLDIER_SCREAM_4_WAV        CAM_SOUNDS_DIR "/scream_05.wav"
#define SOLDIER_SCREAM_5_WAV        CAM_SOUNDS_DIR "/scream_06.wav"
#define SOLDIER_SCREAM_6_WAV        CAM_SOUNDS_DIR "/scream_07.wav"
#define SOLDIER_SCREAM_7_WAV        CAM_SOUNDS_DIR "/scream_08.wav"
#define GAME_OVER_WAV               CAM_SOUNDS_DIR "/gameover.wav"
#define YOU_WIN_WAV                 CAM_SOUNDS_DIR "/youwin.wav"
#define TANK_LOOP_0_WAV             CAM_SOUNDS_DIR "/db_tankloop_01.wav"
#define TANK_LOOP_1_WAV             CAM_SOUNDS_DIR "/db_tankloop_02.wav"
#define TANK_LOOP_2_WAV             CAM_SOUNDS_DIR "/db_tankloop_03.wav"
#define TANK_GUN_WAV                CAM_SOUNDS_DIR "/db_cannon.wav"

// Music files
#define DEFAULT_MENU_MUSIC          "EasyWinners.mid"

#define CAM_OPTIONS_FILE            CAM_DATA_DIR "/options.txt"
#define CAM_HIGH_SCORES_FILE        CAM_DATA_DIR "/highscores"

#define SDL_SUCCEEDED(x)            (x == 0)
#define SDL_FAILED(x)               (x == -1)

// Profiling defines

const int CAM_P_MAIN_LOOP = 0;
const int CAM_P_ACTIVE_TIME = 1;
const int CAM_P_UPDATE_ENTITIES = 2;
const int CAM_P_DRAW_BACKGROUND = 3;
const int CAM_P_DRAW_ENTITIES = 4;
const int CAM_P_DRAW_ALPHA_ENTITIES = 5;
const int CAM_P_DRAW_NON_ALPHA_ENTITIES = 6;
const int CAM_P_DRAW_FOREGROUND = 7;
const int CAM_P_IDLE_TIME = 8;

// Colours
const COLOUR_RGBA TRANSPARENT_COLOUR = { 255, 0, 255, SDL_ALPHA_TRANSPARENT };

#endif // _CAMEL_H_
