/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: EnemyPlane.h
// Desc: Provides the functionality for the enemy planes (boo! hiss!) that will
//       try to thwart our valiant hero. 
//
//       At the moment, the plan is that the AI will be implemented as a 
//       finite state machine that moves from state to state according to
//       internal rules and external conditions. Wherever possible the plan is
//       to use simple rules that result in plausible emergent behaviour,
//       rather than try to account for every possible situation.
//------------------------------------------------------------------------------

#ifndef _ENEMYPLANE_H_
#define _ENEMYPLANE_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "CamelMath.h"
#include "AutoPlane.h"

class EnemyPlane : public AutoPlane 
{
public:
    static const int MAX_NUM_PATROL_POINTS = 10;
    static const int FIRING_RANGE;
    static const int ATTACK_RANGE;
    static const int BREAKOFF_RANGE;
    static const int BINGO_FUEL;

    enum AI_STATES {
        NO_STATE = -1,
        REFUELLING,
        TAKING_OFF,
        PATROLLING,
        FLYING_HOME,
        ATTACKING,
        NUM_STATES
    };
protected:
    WAYPOINT PatrolPoints[MAX_NUM_PATROL_POINTS];

    AI_STATES AI_State;
    uint CurPatrolPoint;
    Entity *CurTarget;

public:
    EnemyPlane(Level *L, PLANE_STATE State, Point2D Pos, bool Inverted, int Direction,
        WAYPOINT PatrolPoints[MAX_NUM_PATROL_POINTS]);
    ~EnemyPlane();

    void Update(uint dt);
    Entity *FindNewTarget();
};

#endif // _ENEMYPLANE_H_
