/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Factory.h
// Desc: This entity represents the small amount of resource management that 
//       there is in the game. The rate at which reinforcements arrive depends
//       upon the number of factories a side has standing.
//------------------------------------------------------------------------------

#ifndef _FACTORY_H_
#define _FACTORY_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Entity.h"

class Factory : public Entity
{
public:
    // Points awarded per unit damage to the factory
    static const int POINTS_VALUE;

    enum FACTORY_TYPE {
        PLATOON_FACTORY,
        TANKSQUAD_FACTORY
    };

    // The hitpoints that a section starts with
    static const int INITIAL_SECTION_HITPOINTS;
    static const int INITIAL_SECTION_HITPOINTS_2;

    // Damage taken from various objects
    static const int DAMAGE_TAKEN_FROM_BULLET;
    static const int DAMAGE_TAKEN_FROM_SOLDIERS_BULLET;
    static const int DAMAGE_TAKEN_FROM_BOMB;
    static const int DAMAGE_TAKEN_FROM_PLANE;

    // Seperate entities could probably be used for each part of the factory
    // but for now I am just using an internal struct
    struct SECTION {
        SECTION();
        SECTION(Point2D WorldPos, int Frame);

        Point2D WorldPos;
        int Frame;
        int HitPoints;
    };
    
    enum SECTION_TYPE {
        NO_SECTION = -1,
        CHIMNEYS,
        LEFT_SIDE,
        MIDDLE,
        RIGHT_SIDE,
        NUM_SECTIONS
    };

    // Constants to do with frames used for different parts of the factory
    static const int FRAME_OFFSETS[NUM_SECTIONS];
protected:
    FACTORY_TYPE FactoryType;

    int SectionWidth;
    int SectionHeight;

    // This entity is made up of multiple sections. The idea is that damage to
    // the factory doesn't destroy it all at once but just a bit at a time.
    SECTION Sections[NUM_SECTIONS];
    SECTION_TYPE SectionHit;

    Factory();

public:
    Factory(Level *L, int x, FACTORY_TYPE FactoryType,  ENT_SIDE Side);
    ~Factory();

    FACTORY_TYPE GetFactoryType() { return FactoryType; }
    void Draw(SDL_Surface *ScreenBuffer);
    void Update(uint dt);
    bool HasCollided(int OtherEntityFrame, Point2D OtherEntityFramePos);
    void FindAndHandleCollisionWithLandscape() {}
	void HandleCollision(Entity *AnEntity);
    void DamageSection(SECTION_TYPE s, int Amount);
};

#endif // _FACTORY_H_
