/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: InputHandler.h
// Desc: Each frame, a member of this class is called to examine the state of 
//       the mouse and keyboard and determine what commands the user is trying
//       to exit. This 'input' can then be retrieved, either to be used by the
//       rest of the game, or to be recorded, or both.
//
//       This class also provides functionality that allows user-defined keys
//       to be assigned to the commands
//------------------------------------------------------------------------------

#ifndef _H_INPUTHANDLER_
#define _H_INPUTHANDLER_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include <assert.h>
#include "globals.h"

class Game;

class InputHandler {
public:
    static const int NUM_MOUSE_BUTTONS = 2;

    enum COMMANDS {
        CLIMB,
        DIVE,
        INVERT,
        FIRE,
        START_ENGINE,
        DROP_BOMB,
        ISSUE_ORDERS,
        FLY_HOME,
        NUM_COMMANDS
    };

    struct COMMAND_INFO {
        char *Name;
        int Option;     // The game option for the command
    };

    // This array gives the corresponding game option for each command
    static const COMMAND_INFO COMMAND_DETAILS[NUM_COMMANDS];
protected:
    static InputHandler *Instance;

    Game *G;

    uchar OldMouseState;
    uchar *OldKeyBoard;
    uchar *KeyBoard;
    int NumKeys;
    int CommandKeys[NUM_COMMANDS];

    InputHandler();
    InputHandler(Game *G);
public:
    bool Commands[NUM_COMMANDS];
    bool *KeyPressed;
    bool MouseButtonPressed[NUM_MOUSE_BUTTONS];

    ~InputHandler();
    static InputHandler *GetInstance(Game *G);
    void UpdateInput();

    int GetCommandKey(uint ACommand);
    void SetCommandKey(uint ACommand);
	uchar *GetKeyBoard() { return KeyBoard; }
    int GetNumKeys() { return NumKeys; }

    bool IsKeyValid(const char *KeyName, int *KeyNumber);


};

#endif // _H_INPUTHANDLER_
