/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: PlaneSpawnPoint.h
// Desc: These entities are responsible for creating planes in the game world.
//       Each spawn point is responsible for one plane. When that plane dies
//       the spawn point waits for a certain amount of time before respawning
//       the plane.
//------------------------------------------------------------------------------

#ifndef _PLANESPAWNPOINT_H_
#define _PLANESPAWNPOINT_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Entity.h"
#include "EnemyPlane.h"

class Plane;

class PlaneSpawnPoint : public Entity
{
    // The runway needs to be raised to stop the plane from colliding 
    // with the grass :P
    static const int HEIGHT_OF_RUNWAY;
protected:
    enum PLANESPAWNPOINT_ACTIONS {
        RESPAWN_PLANE,
        NUM_ACTIONS
    };

    // Rates for various actions are measured in milliseconds
    static const int RESPAWNING_GOOD_PLANE_RATE;
    static const int RESPAWNING_EVIL_PLANE_RATE;

    Plane *CurPlane;
    // These patrol points are used only for enemy planes
    EnemyPlane::WAYPOINT PatrolPoints[EnemyPlane::MAX_NUM_PATROL_POINTS];
    ACTION *Actions[NUM_ACTIONS];

    static void RespawnPlane(void *Object);
public:
    PlaneSpawnPoint(Level *L, int x, ENT_SIDE Side, 
        EnemyPlane::WAYPOINT PatrolPoints[EnemyPlane::MAX_NUM_PATROL_POINTS]);
    ~PlaneSpawnPoint();

    Plane *GetCurPlane();

    void Update(uint dt);
    void Draw(SDL_Surface *ScreenBuffer) {}
    void FindAndHandleCollisionWithLandscape() {}
    void HandleCollision(Entity *AnEntity) {}
};

#endif // _PLANESPAWNPOINT_H_
