/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: PlatoonSpawnPoint.h
// Desc: These entities are responsible for creating new platoons in the game 
//       world. The rate at which platoons are spwaned is dependant upon the 
//       number of factories that a side has alive. If none of a sides 
//       factories are left standing then no more platoons are created.
//------------------------------------------------------------------------------

#ifndef _PLATOONSPAWNPOINT_H_
#define _PLATOONSPAWNPOINT_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Entity.h"

class PlatoonSpawnPoint : public Entity
{
protected:
    enum PLATOONSPAWNPOINT_ACTIONS {
        SPAWN_PLATOON,
        NUM_ACTIONS
    };

    // Rates for various actions are measured in milliseconds
    static const int BASIC_SPAWNING_PLATOON_RATE;

    int OldNumFactories;
    int NumFactories;
    ACTION *Actions[NUM_ACTIONS];

    static void SpawnPlatoon(void *Object);
public:
    PlatoonSpawnPoint(Level *L, int x, ENT_SIDE Side);
    ~PlatoonSpawnPoint();

    void Update(uint dt);
    void Draw(SDL_Surface *ScreenBuffer) {}
    void FindAndHandleCollisionWithLandscape() {}
    void HandleCollision(Entity *AnEntity) {}
};

#endif // _PLATOONSPAWNPOINT_H_
