/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Soldier.h
// Desc: This is the entity that will do most of the fighting (and dying).
//------------------------------------------------------------------------------

#ifndef _SOLDIER_H_
#define _SOLDIER_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Entity.h"
#include "Platoon.h"

class Soldier : public Entity
{
    // The points earned for an EVIL soldiers demise
    static const int POINTS_VALUE;

    // How high above the ground our enemies should aim
    static const int HEIGHT_ABOVE_GROUND;

    // The speed of a soldier is measured in pixels per second. However, the 
    // actual speed of a soldier is random and is in the range
    //              SOLDIER_SPEED +/- SOLDIER_SPEED_RANGE/2
    static const int SOLDIER_SPEED;
    static const int SOLDIER_SPEED_RANGE;
    static const int SOLDIER_SPEED_RANGE_2;

    static const int RANGE_OF_GUN;

    // Constants to do with the frames used to animate the soldier
    static const int NUM_WALKING_FRAMES;
    static const int WALKING_RIGHT_OFFSET;
    static const int WALKING_LEFT_OFFSET;
    static const int FIRING_OFFSET;

    enum SOLDIER_STATE {
        STANDING,
        WALKING,
        FIRING
    };
protected:
    enum SOLDIER_ACTIONS {
        CHANGE_SPEED,
        WALK,
        FIRE,
        NUM_ACTIONS
    };

    // Rates for various actions are measured in milliseconds
    static const int CHANGING_SPEED_RATE;
    static const int WALKING_RATE;
    static const int FIRING_RATE;

    ACTION *Actions[NUM_ACTIONS];

    float Velocity;     // Measured in pixels per second
    int DestinationX;   // Where the soldier wants to go
    int SoldierNum;
    Platoon *CurPlatoon;
    SOLDIER_STATE State;

    // These variables are used to help determine the correct frame to use
    int BaseFrame;
    int WalkingFrame;
    int FiringDirection;

    // When the soldier is firing, this is the point to fire from
    Point2D ShotPos;

    Soldier();
    void CalcFrame();

    static void ChangeSpeed(void *Object);
    static void Walk(void *Object);
    static void Fire(void *Object);
public:
    bool OrdersHaveChanged;
    Platoon::BATTLE_POS BattlePos;

    Soldier(Level *L, int x, int SoldierNum, Platoon *CurPlatoon);
    ~Soldier();

    void Update(uint dt);
    void FindAndHandleCollisionWithLandscape();
	void HandleCollision(Entity *AnEntity);

    int CalculateWorldY(int x, int Width, int Height);
    void PlaceAt(int x);

    static int GetAvailableRange(int HeightDiff);
    static int GetTargetHeight() { return HEIGHT_ABOVE_GROUND; };
};

#endif // _SOLDIER_H_
