/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Sprites.h
// Desc: Functions that load in 1 or more bitmaps that contain the games
//       sprites and plot them to the screen
//------------------------------------------------------------------------------

#ifndef _SPRITES_H_
#define _SPRITES_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "globals.h"
#include "SDL_Interface.h"

class Sprites {
public:
    // The start frame for all of the available sprites
    static const int PLAYER_PLANE_SPRITE;
    static const int SMOKEPARTICLE_SPRITE;
    static const int SMALLEXPLOSION_1_SPRITE;
    static const int SMALLEXPLOSION_2_SPRITE;
    static const int BOMB_SPRITE;
	static const int BULLET_SPRITE;
    static const int MOUSEPOINTER_SPRITE;
    static const int LARGEEXPLOSION_1_SPRITE;
    static const int LARGEEXPLOSION_2_SPRITE;
    static const int ENEMY_PLANE_SPRITE;
    static const int GOOD_SOLDIER_SPRITE;
    static const int EVIL_SOLDIER_SPRITE;
    static const int GOOD_CONTROLLED_ENTITY_FLAG_SPRITE;
    static const int EVIL_CONTROLLED_ENTITY_FLAG_SPRITE;
    static const int GOOD_PLATOON_FACTORY_SPRITE;
    static const int EVIL_PLATOON_FACTORY_SPRITE;
    static const int GOOD_FLAG_SPRITE;
    static const int EVIL_FLAG_SPRITE;
    static const int GAMEOVER_BANNER_SPRITE;
    static const int YOUWIN_BANNER_SPRITE;
    static const int UI_BULLET_SPRITE;
    static const int UI_BOMB_SPRITE;
    static const int UI_HEART_SPRITE;
    static const int UI_SPEEDOMETER_SPRITE;
    static const int UI_FUEL_GUAGE_SPRITE;
    static const int GOOD_TANK_SPRITE;
    static const int EVIL_TANK_SPRITE;
    static const int GOOD_PLATOON_ICON;
    static const int EVIL_PLATOON_ICON;
    static const int GOOD_TANKSQUAD_ICON;
    static const int EVIL_TANKSQUAD_ICON;
    static const int GOOD_TANKSQUAD_FACTORY_SPRITE;
    static const int EVIL_TANKSQUAD_FACTORY_SPRITE;
    static const int TESTFRAME_1;
    static const int TESTFRAME_2;
    static const int NUM_FRAMES = 402;

    static const int COLLISION_THRESHOLD;

    struct FRAME {
        SDL_Rect Rect;
        bool UsesAlphaBlending;
    };
protected:
    static Sprites *Instance;

    SDL_Interface *SDLI;
    SDL_Surface *SpritesIMG;
    static FRAME Frames[NUM_FRAMES];

    Sprites();

    bool InternalDrawFrame(uint Frame, SDL_Surface *Surface, 
        SDL_Rect *SourceRect, SDL_Rect *TargetRect);
public:
    ~Sprites();
    static Sprites *GetInstance();
    bool DrawFrame(uint Frame, SDL_Surface *Surface, int x, int y);
    bool DrawFrame(uint Frame, SDL_Surface *Surface, int x, int y, SDL_Rect FrameArea);
    void GetFrameDims(uint Frame, int *w, int *h);
    bool FindCollision(uint F1, SDL_Rect F1_Area, uint F2, SDL_Rect F2_Area);
    bool FindCollision(uint Frame, SDL_Rect FrameArea,
        SDL_Surface *Surface, SDL_Rect SurfaceArea);
    bool FindCollision(SDL_Surface *S1, const SDL_Rect *S1_Area,
        SDL_Surface *S2, const SDL_Rect *S2_Area);
};

#endif // _SPRITES_H_
