/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: TankSquadSpawnPoint.h
// Desc: These entities are responsible for creating new TankSquads in the game 
//       world. The rate at which TankSquads are spwaned is dependant upon the 
//       number of tank factories that a side has alive. If none of a sides 
//       tank factories are left standing then no more TankSquads are created.
//------------------------------------------------------------------------------

#ifndef _TANKSQUADSPAWNPOINT_H_
#define _TANKSQUADSPAWNPOINT_H_

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Entity.h"

class TankSquadSpawnPoint : public Entity
{
protected:
    enum TANKSQUADSPAWNPOINT_ACTIONS {
        SPAWN_TANKSQUAD,
        NUM_ACTIONS
    };

    // Rates for various actions are measured in milliseconds
    static const int BASIC_SPAWNING_TANKSQUAD_RATE;

    int OldNumFactories;
    int NumFactories;
    ACTION *Actions[NUM_ACTIONS];

    static void SpawnTankSquad(void *Object);
public:
    TankSquadSpawnPoint(Level *L, int x, ENT_SIDE Side);
    ~TankSquadSpawnPoint();

    void Update(uint dt);
    void Draw(SDL_Surface *ScreenBuffer) {}
    void FindAndHandleCollisionWithLandscape() {}
    void HandleCollision(Entity *AnEntity) {}
};

#endif // _TANKSQUADSPAWNPOINT_H_
