;-------------------------------------------------------------------------------
; File: CamelSetp.nsi
; Desc: The Camel installation script
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
; Include Files
;-------------------------------------------------------------------------------
!include "MUI.nsh"

;-------------------------------------------------------------------------------
; Defines
;-------------------------------------------------------------------------------
!define APP_NAME "Camel"
!define APP_VERSION "1.0"
!define APP_COMP_NAME
!define APP_HOME_PAGE "http://www.sourceforge.net/"
!define APP_SM_SHORTCUT "Camel"

; MUI Settings
!define MUI_ABORTWARNING
!define MUI_ICON "camel.ico"
!define MUI_UNICON "${NSISDIR}\Contrib\Graphics\Icons\win-uninstall.ico"
!define MUI_HEADERIMAGE
!define MUI_HEADERIMAGE_BITMAP "header.bmp"

;-------------------------------------------------------------------------------
; Configuration
;-------------------------------------------------------------------------------
Name "${APP_NAME} ${APP_VERSION}"
OutFile "camel-${APP_VERSION}.exe"
InstallDir "$PROGRAMFILES\Camel"
InstallDirRegKey  HKCU "Software\Camel" ""
ShowInstDetails show
ShowUnInstDetails show

;-------------------------------------------------------------------------------
; Global Variables
;-------------------------------------------------------------------------------
Var MUI_TEMP
Var STARTMENU_FOLDER

;-------------------------------------------------------------------------------
; MUI Pages
;-------------------------------------------------------------------------------
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "License.txt"


; Start Menu Folder Page Configuration
!define MUI_STARTMENUPAGE_REGISTRY_ROOT "HKCU"
!define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\Camel"
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"

!insertmacro MUI_PAGE_STARTMENU "Camel" $STARTMENU_FOLDER

!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!define MUI_FINISHPAGE_RUN "$INSTDIR\camel.exe"
!insertmacro MUI_PAGE_FINISH

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

# Set language to use
!insertmacro MUI_LANGUAGE "English"

;-------------------------------------------------------------------------------
; The Installer
;-------------------------------------------------------------------------------
Section "Camel Installation (Required)"

  SectionIn RO

  SetOverwrite try
  ; Set output path to the installation directory.
  SetOutPath $INSTDIR

  ; Put files there
  File "camel.exe"
  File "readme.txt"
  File "camel.ico"
  File "jpeg.dll"
  File "libpng1.dll"
  File "msvcp70.dll"
  File "msvcr70.dll"
  File "paragui.dll"
  File "physfs.dll"
  File "SDL.dll"
  File "SDL_image.dll"
  File "SDL_mixer.dll"
  File "zlib.dll"
  
  SetOutPath "$INSTDIR\data"
  File "data\camelgui.theme"
  File "data\options.txt"
  
  SetOutPath "$INSTDIR\data\camelgui"
  File "data\camelgui\back.bmp"
  File "data\camelgui\background.png"
  File "data\camelgui\button_apply_icon.png"
  File "data\camelgui\button_cancel_icon.png"
  File "data\camelgui\button_close_icon.png"
  File "data\camelgui\button_help_icon.png"
  File "data\camelgui\button_no_icon.png"
  File "data\camelgui\button_ok_icon.png"
  File "data\camelgui\button_yes_icon.png"
  File "data\camelgui\comic.ttf"
  File "data\camelgui\drop_down.bmp"
  File "data\camelgui\editcurs.bmp"
  File "data\camelgui\icon.bmp"
  File "data\camelgui\pointer.png"
  File "data\camelgui\rb_off.bmp"
  File "data\camelgui\rb_on.bmp"
  File "data\camelgui\sb_backh.png"
  File "data\camelgui\sb_backv.png"
  File "data\camelgui\sb_down.bmp"
  File "data\camelgui\sb_drag.bmp"
  File "data\camelgui\sb_dragh.png"
  File "data\camelgui\sb_dragv.png"
  File "data\camelgui\sb_left.bmp"
  File "data\camelgui\sb_right.bmp"
  File "data\camelgui\sb_up.bmp"
  File "data\camelgui\slider_back.png"
  File "data\camelgui\spin_down.bmp"
  File "data\camelgui\spin_up.bmp"
  File "data\camelgui\wnd_close.bmp"
  
  SetOutPath "$INSTDIR\data\graphics"
  File "data\graphics\helpscreen01.png"
  File "data\graphics\helpscreen02.png"
  File "data\graphics\helpscreen03.png"
  File "data\graphics\helpscreen04.png"
  File "data\graphics\helpscreen05.png"
  File "data\graphics\sprites.png"
  File "data\graphics\titlemenupic.png"
  File "data\graphics\uifont.png"
  
  SetOutPath "$INSTDIR\data\levels"
  File "data\levels\L01_bootcamp.lev"
  File "data\levels\L02_trialbyfire.lev"
  File "data\levels\L03_desertrats.lev"
  
  SetOutPath "$INSTDIR\data\levels\intros"
  File "data\levels\intros\I_bootcamp.png"
  File "data\levels\intros\I_trialbyfire.png"
  File "data\levels\intros\I_desertrats.png"
  
  SetOutPath "$INSTDIR\data\levels\parallax"
  File "data\levels\parallax\grasslandL0.png"
  File "data\levels\parallax\grasslandL1.png"
  File "data\levels\parallax\desertL0.png"
  File "data\levels\parallax\desertL1.png"
  
  SetOutPath "$INSTDIR\data\levels\tilesets"
  File "data\levels\tilesets\grassland.png"
  File "data\levels\tilesets\desert.png"
  
  SetOutPath "$INSTDIR\data\music"
  File "data\music\EasyWinners.mid"
  File "data\music\ragdance.mid"
  File "data\music\favorite.mid"

  SetOutPath "$INSTDIR\data\sounds"
  File "data\sounds\bombexpl.wav"
  File "data\sounds\db_cannon.wav"
  File "data\sounds\db_gun_01.wav"
  File "data\sounds\db_gun_02.wav"
  File "data\sounds\db_gun_03.wav"
  File "data\sounds\db_gun_04.wav"
  File "data\sounds\db_gun_05.wav"
  File "data\sounds\db_gun_06.wav"
  File "data\sounds\db_gun_07.wav"
  File "data\sounds\db_scream_01.wav"
  File "data\sounds\db_scream_02.wav"
  File "data\sounds\db_tankloop_01.wav"
  File "data\sounds\db_tankloop_02.wav"
  File "data\sounds\db_tankloop_03.wav"
  File "data\sounds\gameover.wav"
  File "data\sounds\menuclick.wav"
  File "data\sounds\planengi.wav"
  File "data\sounds\planfire.wav"
  File "data\sounds\scream_03.wav"
  File "data\sounds\scream_04.wav"
  File "data\sounds\scream_05.wav"
  File "data\sounds\scream_06.wav"
  File "data\sounds\scream_07.wav"
  File "data\sounds\scream_08.wav"
  File "data\sounds\youwin.wav"

  ; Write the installation path into the registry
  WriteRegStr HKCU SOFTWARE\Camel "Install_Dir" "$INSTDIR"

  ; Write the uninstall keys for Windows
  WriteRegStr HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\Camel" "DisplayName" "Camel"
  WriteRegStr HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\Camel" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\Camel" "NoModify" 1
  WriteRegDWORD HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\Camel" "NoRepair" 1
  ; Create uninstaller
  WriteUninstaller "$INSTDIR\uninstall.exe"

  ; Switch back to $INSTDIR" so that shortcuts start from the correct location
  SetOutPath $INSTDIR
  !insertmacro MUI_STARTMENU_WRITE_BEGIN "Camel"

    ;Create shortcuts
    CreateDirectory "$SMPROGRAMS\$STARTMENU_FOLDER"
    CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Camel.lnk" "$INSTDIR\camel.exe" "" "$INSTDIR\camel.exe" 0
    CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Readme.lnk" "$INSTDIR\readme.txt"
    CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Uninstall.lnk" "$INSTDIR\uninstall.exe" "" "$INSTDIR\uninstall.exe" 0

  !insertmacro MUI_STARTMENU_WRITE_END
  
SectionEnd

;-------------------------------------------------------------------------------
; Uninstaller
;-------------------------------------------------------------------------------
Section "Uninstall"

  ; Remove files and uninstaller
  
  Delete "$INSTDIR\data\camelgui\*.*"
  Delete "$INSTDIR\data\graphics\*.*"
  Delete "$INSTDIR\data\levels\intros\*.*"
  Delete "$INSTDIR\data\levels\parallax\*.*"
  Delete "$INSTDIR\data\levels\tilesets\*.*"
  Delete "$INSTDIR\data\levels\*.*"
  Delete "$INSTDIR\data\music\*.*"
  Delete "$INSTDIR\data\sounds\*.*"
  Delete "$INSTDIR\data\*.*"
  Delete "$INSTDIR\*.*"

  RMDir "$INSTDIR\data\camelgui"
  RMDir "$INSTDIR\data\graphics"
  RMDir "$INSTDIR\data\levels\intros"
  RMDir "$INSTDIR\data\levels\parallax"
  RMDir "$INSTDIR\data\levels\tilesets"
  RMDir "$INSTDIR\data\levels"
  RMDir "$INSTDIR\data\music"
  RMDir "$INSTDIR\data\sounds"
  RMDir "$INSTDIR\data"
  RMDir "$INSTDIR"
  
  ; the code that follows deletes the startmenu items that were installed
  ; along with any empty parent directories
  !insertmacro MUI_STARTMENU_GETFOLDER "Camel" $MUI_TEMP

  Delete "$SMPROGRAMS\$MUI_TEMP\*.*"

  ;Delete empty start menu parent diretories
  StrCpy $MUI_TEMP "$SMPROGRAMS\$MUI_TEMP"

  startMenuDeleteLoop:
    RMDir $MUI_TEMP
    GetFullPathName $MUI_TEMP "$MUI_TEMP\.."

    IfErrors startMenuDeleteLoopDone

    StrCmp $MUI_TEMP $SMPROGRAMS startMenuDeleteLoopDone startMenuDeleteLoop
  startMenuDeleteLoopDone:
  
  ; Remove registry keys
  DeleteRegKey HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\Camel"
  DeleteRegKey HKCU SOFTWARE\Camel

SectionEnd
