/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: Flag.cpp
// Desc: The game of Camel is essentially a game of capture the flag. This
//       entity represents that flag, when a soldier (or tank) from touchs the
//       flag of the opposing side then the game is over and the side that
//       captured the flag has won.
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include <list>
#include <assert.h>
#include "Game.h"
#include "SDL_Interface.h"
#include "Level.h"
#include "Landscape.h"
#include "Sprites.h"
#include "FightingEntity.h"
#include "Flag.h"

using namespace std;

//------------------------------------------------------------------------------
// Flag Implementation
//------------------------------------------------------------------------------
const int Flag::POINTS_VALUE = 1000;

Flag::Flag(Level *L, int x, ENT_SIDE Side) : Entity(L)
{
    this->Side = Side;
    Type = FLAG;

    if (Side == GOOD) {
        Frame = Sprites::GOOD_FLAG_SPRITE;
    } else {
        Frame = Sprites::EVIL_FLAG_SPRITE;
    }
    SPR->GetFrameDims(Frame, &Width, &Height);

    Captured = false;
    // Position the flag in the world
    if (x < 0) {
        x = 0;
    } else if (x > LS->GetWorldPixelWidth() - Width) {
        x = LS->GetWorldPixelWidth() - Width;
    }
    WorldPos.x = x;
    WorldPos.y = LS->CalculatePixelHeight(x) - Height;
}

Flag::~Flag() {}
    
//------------------------------------------------------------------------------
// Name: Update
// Desc: This routine checks through all enemy FightingEntities to see if it 
//       has been captured. if it has been captured then it reports this fact 
//       to its level.
//------------------------------------------------------------------------------
void Flag::Update(uint dt)
{
    int i;
    FightingEntity *CurFE = NULL;
    list<Entity *>::iterator Iter;
    
    if (!Captured) {
        // Loop through all of the entity lists looking for lists that contain
        // FightingEntities
        for (i = 0; i < NUM_ENT_TYPES; i++) {
            if (L->GameEntities[i].size() > 0 
                && dynamic_cast<FightingEntity *>(*(L->GameEntities[i].begin()))) {

                // Loop through all FightingEntities and see if there is a 
                // chance of capture
                for (Iter = L->GameEntities[i].begin();
                    Iter != L->GameEntities[i].end(); Iter++) {
            
                    CurFE = (FightingEntity *)(*Iter);
                    // Test to see if this FightingEntity is valid    
                    if (CurFE->GetSide() != Side && !CurFE->IsFleeing()) {
            
                        // Test for capture
                        if (!(CurFE->Right() < Left() || CurFE->Left() > Right())) {

                            Captured = true;
                            if (Side == EVIL) L->AddToPlayerScore(POINTS_VALUE);
                            break;  // We have been captured so stop checking
                        }
                    }
                }
            }
        }
    }
}

void Flag::HandleCollision(Entity *AnEntity)
{
}
