/*
    Copyright (C) 2003 Alan Broun

    This file is part of Camel.

    Camel is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Camel is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Camel; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//------------------------------------------------------------------------------
// File: PlayerPlane.cpp
// Desc: Provides the functionality for the plane that the player flies.
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
// Include Files
//------------------------------------------------------------------------------
#include "Game.h"
#include "SDL_Interface.h"
#include "InputHandler.h"
#include "Sprites.h"
#include "Level.h"
#include "Landscape.h"
#include "PlayerPlane.h"

//------------------------------------------------------------------------------
// PlayerPlane Implementation
//------------------------------------------------------------------------------
PlayerPlane::PlayerPlane(Level *L, PLANE_STATE State, Point2D Pos, 
                         bool Inverted, int Direction) :
    AutoPlane(L, State, Pos, Inverted, Direction, GOOD) {}

PlayerPlane::~PlayerPlane() 
{
    L->RemovePlayerLife();
}

void PlayerPlane::Update(uint dt)
{
    memset(Commands, false, sizeof(bool)*Plane::NUM_ACTIONS);
    if (FlyingHome) {
        // Check to see if the player wants to come out of autopilot
        if (IH->Commands[InputHandler::CLIMB] 
            || IH->Commands[InputHandler::DIVE] 
            || IH->Commands[InputHandler::INVERT] 
            || IH->Commands[InputHandler::FIRE] 
            || IH->Commands[InputHandler::START_ENGINE]
            || IH->Commands[InputHandler::DROP_BOMB]) {

            StopFlyingHome();
        } else {
            // Otherwise, keep on flying home
            FlyHome();
        }
    } else if (IH->Commands[InputHandler::FLY_HOME]) {
        FlyHome();
    } else {
        // Convey the players commands to the plane

        // Some people have said that they find it easier and more intuitive to
        // control the plane if the keys correspond to clockwise and anti-clockwise
        // motion instead of climbing and diving. In order to accomodate this, all
        // that we have to do is invert the climb and dive keys when the plane is 
        // inverted.
        if (G->GetOption(Game::CLOCK_CONTROLS) != 0 && Inverted) {
            Commands[CLIMB] = IH->Commands[InputHandler::DIVE];
            Commands[DIVE] = IH->Commands[InputHandler::CLIMB];
        } else {
            Commands[CLIMB] = IH->Commands[InputHandler::CLIMB];
            Commands[DIVE] = IH->Commands[InputHandler::DIVE];
        }
        Commands[INVERT] = IH->Commands[InputHandler::INVERT];
        Commands[FIRE] = IH->Commands[InputHandler::FIRE];
        Commands[START_ENGINE] = IH->Commands[InputHandler::START_ENGINE];
	    Commands[DROP_BOMB] = IH->Commands[InputHandler::DROP_BOMB];
    }
    
    Plane::Update(dt);
}
